..
    This file is part of Invenio.
    Copyright (C) 2015 CERN.

    Invenio is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA 02111-1307, USA.

    In applying this license, CERN does not
    waive the privileges and immunities granted to it by virtue of its status
    as an Intergovernmental Organization or submit itself to any jurisdiction.

Authors
=======

Base package for building the Invenio application.

- Adrian Pawel Baran <adrian.pawel.baran@cern.ch>
- Adrian-Tudor Panescu <adrian.tudor.panescu@cern.ch>
- Alessio Deiana <alessio.deiana@cern.ch>
- Alper Cinar <alper@srdc.com.tr>
- Artem Tsikiridis <artem.tsikiridis@cern.ch>
- Benoit Thiell <bthiell@cfa.harvard.edu>
- Björn Oltmanns <bjoern.oltmanns@gmail.com>
- Charalampos Tzovanakis <drjova@cern.ch>
- Dimitrios Semitsoglou-Tsiapos <dsemitso@cern.ch>
- Dinos Kousidis <konstantinos.kousidis@cern.ch>
- Eirini Psallida <eirini.psallida@cern.ch>
- Esteban J. G. Gabancho <esteban.gabancho@cern.ch>
- Frederic Gobry <frederic.gobry@epfl.ch>
- Gabriel Hase <gabriel.hase@cern.ch>
- Georgios Kokosioulis <giokokos@gmail.com>
- Gregory Favre <gregory.favre@cern.ch>
- Grzegorz Szpura <grzegorz.szpura@cern.ch>
- Guillaume Lastecoueres <PX9e@gmx.fr>
- Harris Tzovanakis <me@drjova.com>
- Henning Weiler <henning.weiler@cern.ch>
- Ivan Masár <helix84@centrum.sk>
- Jaime García <jaime.garcia.llopis@gmail.com>
- Jake Cowton <jake.calum.cowton@cern.ch>
- Jan Aage Lavik <jan.age.lavik@cern.ch>
- Javier Delgado Fernandez <javier.delgado.fernandez@cern.ch>
- Javier Martin <javier.martin.montull@cern.ch>
- Javier Martin Montull <javier.martin.montull@cern.ch>
- Jerome Caffaro <jerome.caffaro@cern.ch>
- Jiri Kuncar <jiri.kuncar@cern.ch>
- Joaquim Rodrigues Silvestre <joaquim.rodrigues.silvestre@cern.ch>
- Jochen Klein <klein.jochen@gmail.com>
- Joe Blaylock <jrbl@slac.stanford.edu>
- João Batista <jnfbatista@gmail.com>
- Juan Francisco Pereira Corral <Juan.Francisco.Pereira.Corral@cern.ch>
- Kamil Neczaj <kneczaj@gmail.com>
- Konstantinos Ntemagkos <konstantinos.ntemagkos@cern.ch>
- Krzysztof Lis <krzysztof.lis@cern.ch>
- Kyriakos Liakopoulos <kyriakos.liakopoulos@cern.ch>
- Lars Christian Raae <lars.christian.raae@cern.ch>
- Lars Holm Nielsen <lars.holm.nielsen@cern.ch>
- Leonardo Rossi <leonardo.r@cern.ch>
- Ludmila Marian <ludmila.marian@gmail.com>
- Marco Neumann <marco@crepererum.net>
- Marcus Johansson <marcus.johansson@cern.ch>
- Marko Niinimaki <manzikki@gmail.com>
- Mateusz Susik <mateusz.susik@cern.ch>
- Mathieu Barras <mbarras@gmail.com>
- Mikael Vik <mikael.vik@cern.ch>
- Nicholas Robinson <nicholas.robinson@cern.ch>
- Nicolas Harraudeau <nicolas.harraudeau@cern.ch>
- Nikolaos Kasioumis <nikolaos.kasioumis@cern.ch>
- Olivier Serres <olivier.serres@gmail.com>
- Patrick Glauner <patrick.oliver.glauner@cern.ch>
- Paulo Cabral <paulo.cabral@cern.ch>
- Pedro Gaudêncio <pedro.gaudencio@cern.ch>
- Peter Halliday <phalliday@cornell.edu>
- Petr Brož <petr.broz@heaven-industries.com>
- Piotr Praczyk <piotr.praczyk@gmail.com>
- Radoslav Ivanov <radoslav.ivanov@cern.ch>
- Raquel Jimenez Encinar <r.jimenez.encinar@gmail.com>
- Roman Chyla <roman.chyla@cern.ch>
- Samuele Carli <samuele.carli@cern.ch>
- Samuele Kaplun <samuele.kaplun@cern.ch>
- Sebastian Witowski <sebastian.witowski@cern.ch>
- Stephane Martin <stephane.martin@epfl.ch>
- Thomas Baron <thomas.baron@cern.ch>
- Tibor Simko <tibor.simko@cern.ch>
- Trond Aksel Myklebust <trond.aksel.myklebust@cern.ch>
- Wojciech Ziolek <wojciech.ziolek@cern.ch>
- Yoan Blanc <yoan.blanc@cern.ch>
